@@ -464,12 +464,14 @@ class CartItemSerializer(InventoryValidationMixin, serializers.ModelSerializer):
     image = serializers.SerializerMethodField()
     inventory_quantity = serializers.SerializerMethodField()
     is_uncountable = serializers.SerializerMethodField()
+    product_id = serializers.SerializerMethodField()
 
     class Meta:
         model = CartItem
         fields = (
             "id",
             "product_variant",
+            "product_id",
             "quantity",
             "store",
             "unit_price",
@@ -488,6 +490,9 @@ class CartItemSerializer(InventoryValidationMixin, serializers.ModelSerializer):
             },
         }
 
+    def get_product_id(self, obj):
+        return obj.product_variant.product.id
+
     def get_inventory_quantity(self, obj):
         if obj.inventory:
             return obj.inventory.quantity
@@ -970,17 +975,17 @@ class GenericSerializer(serializers.Serializer):
         )
 
 
+def get_favorite_extras_models():
+    extras_list = []
+    for key, value in settings.FAVORITE_TYPES.items():
+        if "extras" in value:
+            extras_list.extend(value["extras"].keys())
+    return extras_list
+
+
 class FavoriteExtraSerializer(serializers.ModelSerializer):
-    def get_favorite_extras_models():
-        extras_list = []
-
-        for key, value in settings.FAVORITE_TYPES.items():
-            if "extras" in value:
-                extras_list.extend(value["extras"].keys())
-        return extras_list
-
     content_object = GenericSerializer(read_only=True)
-    object_id = serializers.IntegerField(min_value=1, write_only=True)
+    object_id = serializers.IntegerField(min_value=1)
     object_type = serializers.ChoiceField(
         write_only=True, choices=get_favorite_extras_models()
     )
@@ -994,14 +999,27 @@ class FavoriteExtraSerializer(serializers.ModelSerializer):
             "object_type",
         )
 
+    def to_representation(self, instance):
+        data = super().to_representation(instance)
+        extras = get_favorite_extras_models()
+        model_name = instance.content_type.model
+        for extra in extras:
+            if model_name == extra.lower():
+                data["object_type"] = extra
+                break
+        return data
+
 
 class FavoriteSerializer(serializers.ModelSerializer):
     content_object = GenericSerializer(read_only=True)
     extras = FavoriteExtraSerializer(many=True)
-    object_id = serializers.IntegerField(min_value=1, write_only=True)
+    object_id = serializers.IntegerField(min_value=1, required=False)
     object_type = serializers.ChoiceField(
-        write_only=True, choices=list(store_settings.FAVORITE_TYPES.keys())
+        write_only=True,
+        choices=list(store_settings.FAVORITE_TYPES.keys()),
+        required=False,
     )
+    is_available_in_store = serializers.SerializerMethodField()
 
     class Meta:
         model = Favorite
@@ -1012,11 +1030,36 @@ class FavoriteSerializer(serializers.ModelSerializer):
             "object_id",
             "object_type",
             "name",
+            "is_available_in_store",
         )
         extra_kwargs = {
             "name": {"required": True},
         }
 
+    def get_is_available_in_store(self, obj):
+        store_id = self.context["request"].query_params.get("store")
+        type = self.context["request"].query_params.get("type")
+        if type == "Product" and store_id:
+            content_type = ContentType.objects.get_for_model(ProductVariant)
+            try:
+                extra = obj.extras.get(content_type=content_type)
+                inventory = extra.content_object.inventories.get(store=store_id)
+                if inventory.is_uncountable:
+                    return True
+                return inventory.quantity > 0
+            except ObjectDoesNotExist:
+                return False
+        return None
+
+    def to_representation(self, instance):
+        data = super().to_representation(instance)
+        model_name = instance.content_type.model
+        for favorite in store_settings.FAVORITE_TYPES.keys():
+            if model_name == favorite.lower():
+                data["object_type"] = favorite
+                break
+        return data
+
     def _lookup_validation(self, data):
         content_type = ContentType.objects.get_for_model(data["content_object"])
         queryset = Favorite.objects.filter(
@@ -1024,18 +1067,18 @@ class FavoriteSerializer(serializers.ModelSerializer):
             object_id=data["content_object"].id,
             user=self.context["request"].user,
         ).prefetch_related("extras")
+        if self.instance:
+            queryset = queryset.exclude(pk=self.instance.pk)
 
-        if not queryset.exists():
-            return
-
-        for favorite in queryset:
-            content_objects = [
-                instance.content_object for instance in favorite.extras.all()
-            ]
-            if data["extras"] == content_objects:
-                raise serializers.ValidationError(
-                    _(f"You cannot favorite the same item twice")
-                )
+        if queryset.exists():
+            for favorite in queryset:
+                content_objects = [
+                    instance.content_object for instance in favorite.extras.all()
+                ]
+                if set(data["extras"]) == set(content_objects):
+                    raise serializers.ValidationError(
+                        _(f"You cannot favorite the same item twice")
+                    )
 
     def get_object(self, model: models.Model, id: int):
         try:
@@ -1049,14 +1092,22 @@ class FavoriteSerializer(serializers.ModelSerializer):
     def validate(self, attrs):
         validated_data = super().validate(attrs)
         extras_data = {}
-        name = validated_data["name"]
-        object_type = validated_data["object_type"]
-        object_type_model = import_string(
-            store_settings.FAVORITE_TYPES[object_type]["path"]
-        )
-        object_instance = get_object_or_404(
-            object_type_model, pk=validated_data["object_id"]
-        )
+        if self.instance is None:
+            object_type = validated_data["object_type"]
+            object_type_model = import_string(
+                store_settings.FAVORITE_TYPES[object_type]["path"]
+            )
+            object_instance = get_object_or_404(
+                object_type_model, pk=validated_data["object_id"]
+            )
+        else:
+            # when update
+            model_name = self.instance.content_type.model
+            for favorite in store_settings.FAVORITE_TYPES.keys():
+                if model_name == favorite.lower():
+                    object_type = favorite
+            object_instance = self.instance.content_object
+
         for extra in validated_data["extras"]:
             if (
                 extra["object_type"]
@@ -1092,7 +1143,7 @@ class FavoriteSerializer(serializers.ModelSerializer):
         validated_data = {
             "content_object": object_instance,
             "extras": extras,
-            "name": name,
+            "name": validated_data["name"],
         }
         self._lookup_validation(validated_data)
         return validated_data
@@ -1109,6 +1160,16 @@ class FavoriteSerializer(serializers.ModelSerializer):
             raise serializers.ValidationError(detail=e.message_dict)
         return favorite
 
+    def update(self, instance, validated_data):
+        try:
+            favorite = instance.update_favorite(
+                validated_data["name"],
+                validated_data["extras"],
+            )
+        except ValidationError as e:
+            raise serializers.ValidationError(detail=e.message_dict)
+        return favorite
+
 
 class WalletMediaSerializer(serializers.ModelSerializer):
     class Meta:
