@@ -23,7 +23,6 @@ from rest_framework_nested.viewsets import NestedViewSetMixin
 from config import settings as store_settings
 from ob_dj_store.apis.stores.filters import (
     CategoryFilter,
-    FavoriteFilter,
     InventoryFilter,
     OrderFilter,
     PaymentMethodFilter,
@@ -861,6 +860,7 @@ class FavoriteViewSet(
     mixins.ListModelMixin,
     mixins.CreateModelMixin,
     mixins.DestroyModelMixin,
+    mixins.UpdateModelMixin,
     viewsets.GenericViewSet,
 ):
     serializer_class = FavoriteSerializer
@@ -868,11 +868,11 @@ class FavoriteViewSet(
         permissions.IsAuthenticated,
     ]
     queryset = Favorite.objects.all()
-    filterset_class = FavoriteFilter
+    #    filterset_class = FavoriteFilter
 
     def get_queryset(self):
         model = self.request.query_params.get("type")
-        if self.action == "destroy":
+        if self.action in ["destroy", "update"]:
             return self.queryset.filter(user=self.request.user)
         if not model and model not in store_settings.FAVORITE_TYPES:
             raise ValidationError(_("You must provide the favorite type"))
@@ -894,7 +894,14 @@ class FavoriteViewSet(
                 type=openapi.TYPE_STRING,
                 enum=list(store_settings.FAVORITE_TYPES),
                 required=True,
-            )
+            ),
+            openapi.Parameter(
+                "store",
+                in_=openapi.IN_QUERY,
+                description="Store i of favorite products",
+                type=openapi.TYPE_INTEGER,
+                required=True,
+            ),
         ],
         tags=[
             "Favorite",
@@ -915,6 +922,18 @@ class FavoriteViewSet(
     def create(self, request, *args, **kwargs):
         return super().create(request, *args, **kwargs)
 
+    @swagger_auto_schema(
+        operation_summary="Update Item From Favorites",
+        operation_description="""
+            Update  Item From Favorites
+        """,
+        tags=[
+            "Favorite",
+        ],
+    )
+    def update(self, request, *args, **kwargs):
+        return super().update(request, *args, **kwargs)
+
     @swagger_auto_schema(
         operation_summary="Remove Item From Favorites",
         operation_description="""
