@@ -1,3 +1,4 @@
+import logging
 import typing
 
 from django.contrib.contenttypes.models import ContentType
@@ -6,7 +7,9 @@ from django.db import models
 from django.utils.translation import gettext_lazy as _
 
 from config import settings
-from ob_dj_store.core.stores.utils import get_country_by_currency
+from ob_dj_store.utils.helpers import import_gift_payment_function
+
+logger = logging.getLogger(__name__)
 
 
 class ActiveMixin:
@@ -77,8 +80,7 @@ class PaymentManager(models.Manager):
             return instance
         elif gateway == settings.WALLET:
             try:
-                country = get_country_by_currency(currency)
-                wallet = kwargs["user"].wallets.get(country=country)
+                wallet = kwargs["user"].wallets.get(currency=currency)
             except ObjectDoesNotExist:
                 raise ValidationError({"wallet": _("Wallet Not Found")})
             WalletTransaction.objects.create(
@@ -86,6 +88,12 @@ class PaymentManager(models.Manager):
                 type=WalletTransaction.TYPE.DEBIT,
                 amount=kwargs["amount"],
             )
+        elif gateway == settings.GIFT:
+            gift_payment_path = getattr(settings, "GIFT_PAYMENT_METHOD_PATH", None)
+            payment_funciton = import_gift_payment_function(gift_payment_path)
+            payment_funciton(
+                gift_card=orders[0].extra_infos["gift_card"], payment=instance
+            )
         instance.mark_paid()
         return instance
 
