@@ -6,6 +6,7 @@ from django.core.validators import MinValueValidator
 from django.db import models
 from django.utils.translation import gettext_lazy as _
 
+from config import settings
 from ob_dj_store.core.stores.managers import OrderManager
 from ob_dj_store.utils.model import DjangoModelCleanMixin
 
@@ -85,7 +86,15 @@ class Order(DjangoModelCleanMixin, models.Model):
     # Order id of the pickup_car
     car_id = models.PositiveIntegerField(null=True, blank=True)
     # Pick up can be now or a later hour during the day. If pickup_time is not set,
-    extra_infos = models.JSONField(null=True, blank=True)
+    extra_infos = models.JSONField(
+        null=True,
+        blank=True,
+        help_text=f"""
+                gift_details :  {",".join(settings.DIGITAL_PRODUCTS_REQUIRED_KEYS)}
+                gift_card : the id of the gift_card
+
+            """,
+    )
 
     # TODO: add pick_up_time maybe ?
     # audit fields
@@ -119,6 +128,8 @@ class Order(DjangoModelCleanMixin, models.Model):
 
     @property
     def total_amount(self):
+        if self.type_of_order == Order.OrderType.WALLET.value:
+            return Decimal(self.extra_infos["amount"])
         amount = Decimal(
             sum(map(lambda item: Decimal(item.total_amount) or 0, self.items.all()))
         )
